/*
    KiraDev simple ethernet sketch to show the IP address on the display
*/

#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <ETH.h>

#define ETH_CLK_MODE ETH_CLOCK_GPIO0_IN
#define ETH_PHY_ADDR 01
#define ETH_PHY_TYPE ETH_PHY_LAN8720
#define ETH_PHY_POWER 16
#define ETH_PHY_MDC 23
#define ETH_PHY_MDIO 18
#define EMAC_RXD1 26
#define EMAC_TXD1 22
#define EMAC_RXD0 25
#define EMAC_TXD0 19
#define EMAC_TX_EN 21

#define I2C_SDA 04
#define I2C_SCL 14
TwoWire I2Cbus = TwoWire(0);

// Display defines
#define SCREEN_WIDTH    128
#define SCREEN_HEIGHT   32
#define OLED_RESET      -1
#define SCREEN_ADDRESS  0x3C
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &I2Cbus, OLED_RESET);


static bool eth_connected = false;
void WiFiEvent(WiFiEvent_t event)
{
  switch (event) {
    case ARDUINO_EVENT_ETH_START:
      Serial.println("ETH Started");
      //set eth hostname here
      ETH.setHostname("esp32-ethernet");
      break;
    case ARDUINO_EVENT_ETH_CONNECTED:
      Serial.println("ETH Connected");
      break;
    case ARDUINO_EVENT_ETH_GOT_IP:
      Serial.print("ETH MAC: ");
      Serial.print(ETH.macAddress());
      Serial.print(", IPv4: ");
      Serial.print(ETH.localIP());
      if (ETH.fullDuplex()) {
        Serial.print(", FULL_DUPLEX");
      }
      Serial.print(", ");
      Serial.print(ETH.linkSpeed());
      Serial.println("Mbps");
      eth_connected = true;
      break;
    case ARDUINO_EVENT_ETH_DISCONNECTED:
      Serial.println("ETH Disconnected");
      eth_connected = false;
      break;
    case ARDUINO_EVENT_ETH_STOP:
      Serial.println("ETH Stopped");
      eth_connected = false;
      break;
    default:
      break;
            
  }
}
void setup()
{
   Serial.begin(115200);

   ETH.begin(ETH_PHY_ADDR, ETH_PHY_POWER, ETH_PHY_MDC, ETH_PHY_MDIO, ETH_PHY_TYPE, ETH_CLK_MODE);

 // initialize RED LED on GPIO33 as an output.
  pinMode(33, OUTPUT);

 // initialize GREEN LED on GPIO12 as an output.
  pinMode(12, OUTPUT);

 // initialize BLUE LED on GPIO02 as an output.
  pinMode(02, OUTPUT);

  // Initialize I2C with our defined pins
  I2Cbus.begin(I2C_SDA, I2C_SCL, 100000);

  Serial.println("Initialize display");

  // SSD1306_SWITCHCAPVCC = generate display voltage from 3.3V internally
  if(!display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS))
  {
    Serial.printf("SSD1306 OLED display failed to initalize.\nCheck that display SDA is connected to pin %d and SCL connected to pin %d\n", I2C_SDA, I2C_SCL);
    while (true);
  }

  Serial.println("Show 'Hello World!' on display");
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  display.print("Hello\nWorld!");
  display.display();
  Serial.println("ETH Started");
  Serial.print("ETH MAC: ");
  Serial.print(ETH.macAddress());
  Serial.println(", IPv4: ");
  Serial.print(ETH.localIP());
  if (ETH.fullDuplex()) {
  Serial.println(", FULL_DUPLEX");
      }
  Serial.print(", ");
  Serial.print(ETH.linkSpeed());
  Serial.println("Mbps");
  delay(2000);
  Serial.println("Show ethernet address on display");
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(1);
  display.setTextColor(SSD1306_WHITE);
  Serial.print(ETH.localIP());
  display.print("Local IP");
  display.setCursor(0, 16);
  display.print(ETH.localIP());
  display.display();

}

void loop()
{
{
  if (eth_connected == true) {
  digitalWrite(33, HIGH); // turn the RED LED on if true
  } else { 
  digitalWrite(33, LOW);  // turn the RED LED off if false
  }
} 
  digitalWrite(12, HIGH); // turn the GREEN LED on
  delay(2000);             // wait for 200 milliseconds
  digitalWrite(12, LOW);  // turn the GREEN LED off
  delay(2000);             // wait for 2000 milliseconds

  digitalWrite(02, HIGH); // turn the BLUE LED on
  delay(1000);             // wait for 100 milliseconds
  digitalWrite(02, LOW);  // turn the BLUE LED off
  delay(1000);             // wait for 1000 milliseconds

  Serial.print(", IPv4: ");
  Serial.print(ETH.localIP());
  if (ETH.fullDuplex()) {
   Serial.print(", FULL_DUPLEX");
   }
  Serial.print(", ");
  Serial.print(ETH.linkSpeed());
  Serial.println("Mbps");

}



  
