/*
 * A simple sketch for the KiraDev PCB that will change the display when IR is received. 
 * Use the serial monitor to read the data.
 */

#include <Arduino.h>
#include <IRrecv.h>
#include <IRutils.h>
#include <Wire.h>
#include <Adafruit_SSD1306.h>

#define I2C_SDA 04
#define I2C_SCL 14
TwoWire I2Cbus = TwoWire(0);

// Display defines
#define SCREEN_WIDTH    128
#define SCREEN_HEIGHT   32
#define OLED_RESET      -1
#define SCREEN_ADDRESS  0x3C
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &I2Cbus, OLED_RESET);

const uint16_t kRecvPin = 34;  // KiraOne IR pin

IRrecv irrecv(kRecvPin);

decode_results results;

void setup() {
  Serial.begin(115200);
  irrecv.enableIRIn();  // Start the receiver
  while (!Serial)  // Wait for the serial connection to be establised.
    delay(50);
  Serial.println();
  Serial.print("IRrecvDemo is now running and waiting for IR message on Pin ");
  Serial.println(kRecvPin);
    
  pinMode(13, INPUT); // required to use the IR receiver   
  pinMode(33, OUTPUT); // initialize RED LED on GPIO33 as an output.

    // Initialize I2C with our defined pins
  I2Cbus.begin(I2C_SDA, I2C_SCL, 100000);

 Serial.println("Initialize display");

  // SSD1306_SWITCHCAPVCC = generate display voltage from 3.3V internally
  if(!display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS))
  {
    Serial.printf("SSD1306 OLED display failed to initalize.\nCheck that display SDA is connected to pin %d and SCL connected to pin %d\n", I2C_SDA, I2C_SCL);
    while (true);
  }
  Serial.println("Show 'waiting..' on display");
  display.clearDisplay();
  
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  display.print("waiting..");
  display.display();
  //delay(3000);

}

void loop() {


   if (irrecv.decode(&results)) {
    serialPrintUint64(results.value, HEX);
    Serial.println("");
    digitalWrite(33, HIGH); // flash the RED LED as IR is received
    delay(200);              // wait for 200 milliseconds
    digitalWrite(33, LOW);  // turn the RED LED off
    display.clearDisplay();
    display.setCursor(0, 0);
    display.setTextSize(2);
    display.setTextColor(SSD1306_WHITE);
    Serial.println("Show 'IR' on display");
    display.print("IR");
    display.display();
    delay(1500);              // wait for 1500 milliseconds
    display.clearDisplay();
    display.setCursor(0, 0); 
    display.print("waiting..");
    display.display();
    irrecv.resume();        // Receive the next IR signal
  }
  delay(200);
  
 
}
