/*
 * A simple sketch for the KiraDev PCB to demonstrate the IR blast capability.
 * The IR output will loop continuously through the examples.
 * 
 * This example code uses the esp8266 library from Ken Sherrrif, please credit if you decide to use.
 * Copyright 2009 Ken Shirriff, http://arcfn.com
 */

#include <Arduino.h>
#include <IRremoteESP8266.h>
#include <IRsend.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define I2C_SDA 04
#define I2C_SCL 14
TwoWire I2Cbus = TwoWire(0);

// Display defines
#define SCREEN_WIDTH    128
#define SCREEN_HEIGHT   32
#define OLED_RESET      -1
#define SCREEN_ADDRESS  0x3C
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &I2Cbus, OLED_RESET);

const uint16_t kIrLed = 17;  // IR Tx pin

IRsend irsend(kIrLed);  

// Example of data captured by IRrecvDumpV2.ino
uint16_t rawData[67] = {9000, 4500, 650, 550, 650, 1650, 600, 550, 650, 550,
                        600, 1650, 650, 550, 600, 1650, 650, 1650, 650, 1650,
                        600, 550, 650, 1650, 650, 1650, 650, 550, 600, 1650,
                        650, 1650, 650, 550, 650, 550, 650, 1650, 650, 550,
                        650, 550, 650, 550, 600, 550, 650, 550, 650, 550,
                        650, 1650, 600, 550, 650, 1650, 650, 1650, 650, 1650,
                        650, 1650, 650, 1650, 650, 1650, 600};
// Example Samsung A/C state captured from IRrecvDumpV2.ino
uint8_t samsungState[kSamsungAcStateLength] = {
    0x02, 0x92, 0x0F, 0x00, 0x00, 0x00, 0xF0,
    0x01, 0xE2, 0xFE, 0x71, 0x40, 0x11, 0xF0};

void setup() {
  irsend.begin();
  Serial.begin(115200, SERIAL_8N1);
  
  while (!Serial)  // Wait for the serial connection to be establised.
    delay(50);
  Serial.println();
  Serial.println("IRsendDemo is now running");
  pinMode(02, OUTPUT); // initialize BLUE LED on GPIO2 as an output.

    // Initialize I2C with our defined pins
  I2Cbus.begin(I2C_SDA, I2C_SCL, 100000);

 Serial.println("Initialize display");

  // SSD1306_SWITCHCAPVCC = generate display voltage from 3.3V internally
  if(!display.begin(SSD1306_SWITCHCAPVCC, SCREEN_ADDRESS))
  {
    Serial.printf("SSD1306 OLED display failed to initalize.\nCheck that display SDA is connected to pin %d and SCL connected to pin %d\n", I2C_SDA, I2C_SCL);
    while (true);
  }

  Serial.println("Show 'Hello World!' on display");
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  display.print("Hello\nWorld!");
  display.display();
  delay(3000);
  display.clearDisplay();
}   
  


void loop() {
  Serial.println("NEC");
  irsend.sendNEC(0x00FFE01FUL);
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  Serial.println("Show 'NEC' on display");
  display.print("NEC");
  display.display();
  digitalWrite(02, HIGH); // flash the BLUE LED as IR is transmitted
  delay(50);              // wait for 50 milliseconds
  digitalWrite(02, LOW);  // turn the BLUE LED off
  delay(2000);
  display.clearDisplay();

    Serial.println("Sony");
  irsend.sendNEC(0x00FFE01FUL);
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  Serial.println("Show 'Sony' on display");
  display.print("Sony");
  display.display();
  Serial.println("Sony");
  irsend.sendSony(0xa90, 12, 2);  // 12 bits & 2 repeats
  digitalWrite(02, HIGH); // flash the BLUE LED as IR is transmitted
    delay(50);              // wait for 50 milliseconds
    digitalWrite(02, LOW);  // turn the BLUE LED off
  delay(2000);

  Serial.println("Raw");
  irsend.sendNEC(0x00FFE01FUL);
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  Serial.println("Show 'RAw' on display");
  display.print("Raw data");
  display.display();
  Serial.println("a rawData capture from IRrecvDumpV2");
  irsend.sendRaw(rawData, 67, 38);  // Send a raw data capture at 38kHz.
    digitalWrite(02, HIGH); // flash the BLUE LED as IR is transmitted
    delay(50);              // wait for 50 milliseconds
    digitalWrite(02, LOW);  // turn the BLUE LED off
  delay(2000);
  
  Serial.println("Samsung");
  irsend.sendNEC(0x00FFE01FUL);
  display.clearDisplay();
  display.setCursor(0, 0);
  display.setTextSize(2);
  display.setTextColor(SSD1306_WHITE);
  Serial.println("Show 'Samsung' on display");
  display.print("Samsung");
  display.display();
  Serial.println("a Samsung A/C state from IRrecvDumpV2");
  irsend.sendSamsungAC(samsungState);
    digitalWrite(02, HIGH); // flash the BLUE LED as IR is transmitted
    delay(50);              // wait for 50 milliseconds
    digitalWrite(02, LOW);  // turn the BLUE LED off
  delay(2000);
}
